@@ -1,6 +1,6 @@
 package Bio::Roary::CommandLine::Common;
 # ABSTRACT: Common command line settings
-$Bio::Roary::CommandLine::Common::VERSION = '2.3.4';
+$Bio::Roary::CommandLine::Common::VERSION = '3.0.0';
 
 use Moose;
 use FindBin;
@@ -32,7 +32,7 @@ before 'run' => sub {
 	my $OPSYS = $^O;
 	my $BINDIR = "$FindBin::RealBin/../binaries/$OPSYS";
 
-    for my $dir ($BINDIR, "$BINDIR/../common", $FindBin::RealBin) {
+    for my $dir ($BINDIR, $FindBin::RealBin) {
       if (-d $dir) {
         $ENV{PATH} .= ":$dir";
        }
@@ -54,7 +54,7 @@ Bio::Roary::CommandLine::Common - Common command line settings
 
 =head1 VERSION
 
-version 2.3.4
+version 3.0.0
 
 =head1 SYNOPSIS
 
