@@ -1,13 +1,12 @@
 package Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides;
-$Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides::VERSION = '2.3.4';
+$Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides::VERSION = '3.0.0';
 # ABSTRACT: Take in a multifasta file of nucleotides, convert to proteins and align with muscle
 
 
 use Moose;
 use Getopt::Long qw(GetOptionsFromArray);
 use Bio::Roary::AnnotateGroups;
-use Bio::Roary::External::Muscle;
-use Bio::Roary::External::Revtrans;
+use Bio::Roary::External::Prank;
 use Bio::Roary::Output::GroupsMultifastaProtein;
 use Bio::Roary::SortFasta;
 extends 'Bio::Roary::CommandLine::Common';
@@ -16,24 +15,28 @@ extends 'Bio::Roary::CommandLine::Common';
 has 'args'        => ( is => 'ro', isa => 'ArrayRef', required => 1 );
 has 'script_name' => ( is => 'ro', isa => 'Str',      required => 1 );
 has 'help'        => ( is => 'rw', isa => 'Bool',     default  => 0 );
-has 'translation_table'  => ( is => 'rw', isa => 'Int',      default => 11 );
 
 has 'nucleotide_fasta_files'  => ( is => 'rw', isa => 'ArrayRef' );
 has '_error_message'          => ( is => 'rw', isa => 'Str' );
+has 'verbose'                 => ( is => 'rw', isa => 'Bool', default => 0 );
 
 sub BUILD {
     my ($self) = @_;
 
-    my ( $nucleotide_fasta_files, $help,$translation_table );
+    my ( $nucleotide_fasta_files, $help,$verbose );
 
     GetOptionsFromArray(
         $self->args,
-        't|translation_table=i'     => \$translation_table,
+		'v|verbose'                 => \$verbose,
         'h|help'              => \$help,
     );
+	
+    if ( defined($verbose) ) {
+        $self->verbose($verbose);
+        $self->logger->level(10000);
+    }
 
     $self->help($help) if(defined($help));
-    $self->translation_table($translation_table)             if (defined($translation_table) );
     if ( @{ $self->args } == 0 ) {
         $self->_error_message("Error: You need to provide at least 1 FASTA file");
     }
@@ -61,41 +64,25 @@ sub run {
       
       my $sort_fasta_before = Bio::Roary::SortFasta->new(
          input_filename   => $fasta_file,
+		 make_multiple_of_three => 1,
        );
       $sort_fasta_before->sort_fasta->replace_input_with_output_file;
-      
-      my $multifasta_protein_obj = Bio::Roary::Output::GroupsMultifastaProtein->new(
-          nucleotide_fasta_file => $fasta_file,
-          translation_table     => $self->translation_table
-        );
-      $multifasta_protein_obj->convert_nucleotide_to_protein();
-      
-      my $seg = Bio::Roary::External::Muscle->new(
-        fasta_files => [$multifasta_protein_obj->output_filename],
-        job_runner  => 'Local'
-      );
-      $seg->run();
-      
-      my $sort_fasta_after_muscle = Bio::Roary::SortFasta->new(
-         input_filename   => $multifasta_protein_obj->output_filename. '.aln',
-       );
-      $sort_fasta_after_muscle->sort_fasta->replace_input_with_output_file;
-
-      my $revtrans= Bio::Roary::External::Revtrans->new(
-        nucleotide_filename => $fasta_file,
-        protein_filename  => $multifasta_protein_obj->output_filename. '.aln',
-        output_filename   => $fasta_file.'.aln',
-        translation_table => $self->translation_table
-      );
-      $revtrans->run();
-      
+	  
+	  my $prank_obj = Bio::Roary::External::Prank->new(
+	    input_filename  => $fasta_file,
+	    output_filename => $fasta_file.'.aln',
+	    job_runner      => 'Local',
+		logger          => $self->logger,
+		verbose         => $self->verbose
+	  );
+	  $prank_obj->run();
+	  
       my $sort_fasta_after_revtrans = Bio::Roary::SortFasta->new(
-         input_filename   => $fasta_file.'.aln',
+         input_filename      => $fasta_file.'.aln',
+		 remove_nnn_from_end => 1,
        );
       $sort_fasta_after_revtrans->sort_fasta->replace_input_with_output_file;
-      
-      unlink($multifasta_protein_obj->output_filename);
-      unlink($multifasta_protein_obj->output_filename. '.aln');
+      unlink($fasta_file);
     }
 }
 
@@ -109,9 +96,6 @@ sub usage_text {
     # Transfer the annotation from the GFF files to the group file
     protein_muscle_alignment_from_nucleotides protein_fasta_1.faa protein_fasta_2.faa
     
-    # Use a different translation table (default 11)
-    protein_muscle_alignment_from_nucleotides -t 1 protein_fasta_1.faa protein_fasta_2.faa
-    
     # This help message
     protein_muscle_alignment_from_nucleotides -h
 
@@ -134,7 +118,7 @@ Bio::Roary::CommandLine::ProteinMuscleAlignmentFromNucleotides - Take in a multi
 
 =head1 VERSION
 
-version 2.3.4
+version 3.0.0
 
 =head1 SYNOPSIS
 
