@@ -1,5 +1,5 @@
 package Bio::Roary::CommandLine::RoaryPostAnalysis;
-$Bio::Roary::CommandLine::RoaryPostAnalysis::VERSION = '2.3.4';
+$Bio::Roary::CommandLine::RoaryPostAnalysis::VERSION = '3.0.0';
 # ABSTRACT: Perform the post analysis on the pan genome
 
 
@@ -128,7 +128,8 @@ sub run {
         job_runner          => $self->job_runner,
         translation_table   => $self->translation_table,
         core_definition     => $self->core_definition,
-        cpus                => $self->cpus
+        cpus                => $self->cpus,
+		verbose             => $self->verbose,
       );
       $seg->run();
 	
@@ -207,7 +208,7 @@ Bio::Roary::CommandLine::RoaryPostAnalysis - Perform the post analysis on the pa
 
 =head1 VERSION
 
-version 2.3.4
+version 3.0.0
 
 =head1 SYNOPSIS
 
