@@ -1,5 +1,5 @@
 package Bio::Roary::External::ProteinMuscleAlignmentFromNucleotides;
-$Bio::Roary::External::ProteinMuscleAlignmentFromNucleotides::VERSION = '2.3.4';
+$Bio::Roary::External::ProteinMuscleAlignmentFromNucleotides::VERSION = '3.0.0';
 # ABSTRACT: Take in a multifasta file of nucleotides, convert to proteins and align with muscle
 
 
@@ -25,7 +25,12 @@ sub _build__memory_required_in_mb {
 
 sub _command_to_run {
     my ( $self, $fasta_files, ) = @_;
-    return $self->exec. " -t ".$self->translation_table." ". join( " ", @{$fasta_files}  );
+	my $verbose = "";
+	if($self->verbose)
+	{
+		$verbose = '-v';
+	}
+    return $self->exec. " ".$verbose." ". join( " ", @{$fasta_files}  );
 }
 
 sub _build__core_alignment_cmd {
@@ -84,7 +89,7 @@ Bio::Roary::External::ProteinMuscleAlignmentFromNucleotides - Take in a multifas
 
 =head1 VERSION
 
-version 2.3.4
+version 3.0.0
 
 =head1 SYNOPSIS
 
